[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [12104] trunk/blender: made sticky UV editing options more accessible by adding them to a popup in the header .

Campbell Barton cbarton at metavr.com
Sat Sep 22 08:58:40 CEST 2007


Revision: 12104
          http://projects.blender.org/plugins/scmsvn/viewcvs.php?view=rev&root=bf-blender&revision=12104
Author:   campbellbarton
Date:     2007-09-22 08:58:40 +0200 (Sat, 22 Sep 2007)

Log Message:
-----------
made sticky UV editing options more accessible by adding them to a popup in the header.
Changed how the sticky setting is stored in DNA - (as a char rather then 2 flags).
replaced the UV/FACE icon with another needed for the sticky menu.
removed 2 unused icons.

commented the UV transform panel since it only had 2 buttons in it.

depgraph update calls needed to be added to Ctrl+V/E/F menu's because some commands were crashing.

Modified Paths:
--------------
    trunk/blender/release/datafiles/blenderbuttons
    trunk/blender/source/blender/blenloader/intern/readfile.c
    trunk/blender/source/blender/include/BIF_editsima.h
    trunk/blender/source/blender/include/BIF_resources.h
    trunk/blender/source/blender/include/BIF_space.h
    trunk/blender/source/blender/makesdna/DNA_space_types.h
    trunk/blender/source/blender/src/blenderbuttons.c
    trunk/blender/source/blender/src/drawimage.c
    trunk/blender/source/blender/src/editmesh_mods.c
    trunk/blender/source/blender/src/editsima.c
    trunk/blender/source/blender/src/header_image.c
    trunk/blender/source/blender/src/space.c

Modified: trunk/blender/release/datafiles/blenderbuttons
===================================================================
(Binary files differ)

Modified: trunk/blender/source/blender/blenloader/intern/readfile.c
===================================================================
--- trunk/blender/source/blender/blenloader/intern/readfile.c	2007-09-21 20:46:17 UTC (rev 12103)
+++ trunk/blender/source/blender/blenloader/intern/readfile.c	2007-09-22 06:58:40 UTC (rev 12104)
@@ -6101,20 +6101,6 @@
 				sce->toolsettings->unwrapper = 1;
 			}
 
-			/* enable uv editor local sticky by default */
-			for (sc= main->screen.first; sc; sc= sc->id.next) {
-				ScrArea *sa;
-				for (sa= sc->areabase.first; sa; sa= sa->next) {
-					SpaceLink *sl;
-					for (sl= sa->spacedata.first; sl; sl= sl->next) {
-						if(sl->spacetype==SPACE_IMAGE) {
-							SpaceImage *sima= (SpaceImage*)sl;
-							if(!(sima->flag & SI_STICKYUVS))
-								sima->flag |= SI_LOCALSTICKY;
-						}
-					}
-				}
-			}
 			if(sce->r.mode & R_PANORAMA) {
 				/* all these checks to ensure saved files with cvs version keep working... */
 				if(sce->r.xsch < sce->r.ysch) {

Modified: trunk/blender/source/blender/include/BIF_editsima.h
===================================================================
--- trunk/blender/source/blender/include/BIF_editsima.h	2007-09-21 20:46:17 UTC (rev 12103)
+++ trunk/blender/source/blender/include/BIF_editsima.h	2007-09-22 06:58:40 UTC (rev 12104)
@@ -94,7 +94,6 @@
 void stitch_uv_tface(int mode);
 void unlink_selection(void);
 void select_linked_tface_uv(int mode);
-void toggle_uv_select(int mode);
 void pin_tface_uv(int mode);
 void weld_align_menu_tface_uv(void);
 void weld_align_tface_uv(char tool);

Modified: trunk/blender/source/blender/include/BIF_resources.h
===================================================================
--- trunk/blender/source/blender/include/BIF_resources.h	2007-09-21 20:46:17 UTC (rev 12103)
+++ trunk/blender/source/blender/include/BIF_resources.h	2007-09-22 06:58:40 UTC (rev 12104)
@@ -123,9 +123,9 @@
 	ICON_AXIS_SIDE,
 	ICON_AXIS_FRONT,
 	ICON_AXIS_TOP,
-	ICON_DRAW_UVFACES,
-	ICON_STICKY_UVS,
-	ICON_STICKY2_UVS,
+	ICON_STICKY_UVS_LOC,
+	ICON_STICKY_UVS_DISABLE,
+	ICON_STICKY_UVS_VERT,
 	ICON_PREV_KEYFRAME,
 	ICON_NEXT_KEYFRAME,
 	ICON_ENVMAP,
@@ -317,8 +317,8 @@
 	ICON_HOME,
 	ICON_CLIPUV_DEHLT,
 	ICON_CLIPUV_HLT,
-	ICON_SOME_WACKY_VERTS_AND_LINES,
-	ICON_A_WACKY_VERT_AND_SOME_LINES,
+	ICON_BLANK2,
+	ICON_BLANK3,
 	ICON_VPAINT_COL,
 	ICON_RESTRICT_SELECT_OFF,
 	ICON_RESTRICT_SELECT_ON,

Modified: trunk/blender/source/blender/include/BIF_space.h
===================================================================
--- trunk/blender/source/blender/include/BIF_space.h	2007-09-21 20:46:17 UTC (rev 12103)
+++ trunk/blender/source/blender/include/BIF_space.h	2007-09-22 06:58:40 UTC (rev 12104)
@@ -65,8 +65,8 @@
 #define IMAGE_HANDLER_CURVES		32
 #define IMAGE_HANDLER_PREVIEW		33
 #define IMAGE_HANDLER_GAME_PROPERTIES	34
-#define IMAGE_HANDLER_TRANSFORM_PROPERTIES	35
-#define IMAGE_HANDLER_VIEW_PROPERTIES	36
+#define IMAGE_HANDLER_VIEW_PROPERTIES	35
+/*#define IMAGE_HANDLER_TRANSFORM_PROPERTIES	36*/
 
 /* action handler codes */
 #define ACTION_HANDLER_PROPERTIES	40

Modified: trunk/blender/source/blender/makesdna/DNA_space_types.h
===================================================================
--- trunk/blender/source/blender/src/blenderbuttons.c	2007-09-21 20:46:17 UTC (rev 12103)
+++ trunk/blender/source/blender/src/blenderbuttons.c	2007-09-22 06:58:40 UTC (rev 12104)
@@ -1,2075 +1,2078 @@
 /* DataToC output of file <blenderbuttons> */
 
-int datatoc_blenderbuttons_size= 66177;
+int datatoc_blenderbuttons_size= 66284;
 char datatoc_blenderbuttons[]= {
-137,
- 80, 78, 71, 13, 10, 26, 10,  0,  0,  0, 13, 73, 72, 68, 82,  0,  0,  2,  0,  0,  0,  1,  0,  8,  6,  0,  0,  0,197,144,206,103,
-  0,  0,  0,  6, 98, 75, 71, 68,  0,255,  0,255,  0,255,160,189,167,147,  0,  0,  0,  9,112, 72, 89,115,  0,  0, 11, 19,  0,  0,
- 11, 19,  1,  0,154,156, 24,  0,  0,  0,  7,116, 73, 77, 69,  7,215,  8, 19, 12, 42, 10, 55,151,233,213,  0,  0, 32,  0, 73, 68,
- 65, 84,120,218,236, 93,121, 92, 84, 85,255,126,206,157,157,125, 17, 81,113,  1, 21,215, 92,192, 61,151, 24,  3, 75,127,165,169,
-160,153, 37,165,111, 76,166,173,246,106,219,251,150,111,166,185, 85,190, 89, 58,190,165,105,169, 37,168,105,185, 36,232,160,166,
-228,174, 88, 46, 40,138,  8,138,224, 48, 48,195,108,119,102,238,249,253, 49, 51, 52, 32,195, 44,160, 97,205,243,113, 62,204,189,
-115,239,215,115,239, 57,231,251,124,151,179,144,222,189,123, 83,248,224,131, 15, 62,248,224,131, 15,127, 43, 48,190, 87,224,131,
- 15, 62,248,224,131, 15,127, 31,156, 60,149,  5,  0, 32,190,  8,128, 15, 62,248,224,131, 15, 62,248, 34,  0, 62,248,224,131, 15,
- 62,248,224,131,207,  0,240,193,  7, 31,124,240,193,  7, 31,124,  6,128, 15, 62,248,224,131, 15, 62,248,240,151,  0,223,241, 96,
-250,244,233,196, 91, 65, 43, 86,172,184, 99, 44,129, 79,158, 79, 94, 61,160, 43, 86,172,248,211,202,151,157,157, 77, 19, 18, 18,
-136,175, 62,238, 95,121,167, 79,159,246,186,241,245,238,221, 27,190,250,104,218,242, 78,157, 58,229,181,188,184,184,184,191,189,
- 60,143, 13,128,191, 51,100, 50, 89,141, 23, 40,151,203, 73, 83, 46,231,202,149, 43, 65,  8, 33,190,154,243,174,142, 39, 77,154,
-132,140,140,140,234,227,228,228,228,191,196,187,220,185,235,100,189,138, 96,212,200,248,191,116,155,145,132,110,133,216,208, 17,
- 49, 96, 81,133, 93,200,211,191,219,100,219, 98, 83,213, 49, 62,252, 77, 35,  0,247,162,177,238,220,185, 51, 97,219,182,109, 10,
-251,241,152, 49, 99,164,163, 70,141,202,110, 10, 47,131, 82,171,238,108,170,188, 42,147,201,104, 65, 65,  1,  0, 32, 58, 58, 26,
-  0,238, 11, 37, 82,219,184,178, 25, 88, 78, 61,115,119,229,110,220,184,209,109, 67, 77, 38,147,209, 77,155, 54, 85, 31,111,221,
-186, 21, 73, 73, 73,213,199, 25, 25, 25,244,207, 50,  2,250,244,233, 67,  1,224,196,137, 19,164, 49,174,219,246,131,188, 30,  3,
- 64,222,224,250,139,138,105,  3,  0,184,101, 48,192,172, 55, 90, 79, 86,168,  1,  0, 41, 41, 41, 72, 76, 76,116, 90,190, 85,137,
-171,104,236,205, 88,143,254,127,233,239, 82, 55,234, 69,130,208, 23,207,194,176,109, 43, 84,170,177, 80,  1,136,151, 44,198,187,
-146, 19,104, 35,  6,202, 12,249,120, 87, 63,193,163,255, 55, 43, 43, 43, 33, 61, 61, 93,225,120, 46, 37, 37, 69,154,152,152,152,
-221,148,250, 86, 99,233,128,251,225,121,239,  6, 90, 53, 19,147,  0, 65, 48, 49,138,133,212, 88,161,103,170,244,106,174,202,192,
-254, 45,102,199,185, 52,  0,118,238,220,153, 96,255,219, 80,162,182, 43,146,185,155,230, 33,160, 77, 48,170,174, 87,226,189,  9,
-239, 42,182,109,219,  6,159, 53,236, 26,114,185,156, 68, 71, 71,211,130,130,  2, 20, 20, 20, 96,247,238,221, 77,214,147,176,215,
-181, 92, 46, 39,114,185, 92, 32,147,201, 76,139, 22, 45, 58,  6,  0,179,103,207,238, 87,223,189, 99,199,142,173,254,110, 54, 91,
-192,154,140, 96,141, 44, 88,214,250, 49,155,205,152, 61,123,182, 71,101,113, 36,255,186,144,148,148,244,167, 26,  1,238, 24, 63,
-125,250,244,113, 41, 99,212,200,120,226, 13,201,187,141,144, 32,228, 94,249, 14, 18,180,134,  5,135, 80,250,229, 73,156,201, 87,
- 98,220, 71,107,220,186, 61,246,102,172,155,132,110,133,162,187,194,165, 34,150,140,122, 23, 97, 99,166,161,248,213,120, 64,175,
-170, 62,127, 82,255, 79,156,  4,  0, 61, 48, 76,146,130,189,161, 39, 16,  2,160,143,170,143,219,237,183, 54,210,211,211, 21,233,
-233,233, 77, 66, 95,217,203,216, 24, 58,224,126,120,222,198,198,144, 94,113,228,233,168, 24,254,203,201, 83,120,205,187, 70, 49,
-124,210,156,232, 42, 43, 57, 49, 34, 45,235,126,202,180, 76,121, 44,201,226,142, 28, 66,200, 13, 15,156,204, 86,110,200,155,229,
-129,188,165,119,213,  0,216,182,109,155, 98,211,191,222,198,132, 15,230, 43, 70,141, 26, 69, 26,210,192,236,196, 15,  0,183,117,
- 74, 32, 28,120,107,239,251, 80, 95, 81, 65,246,124,211, 34, 50,103, 29,226,207, 46,163,163, 17,240,232,163,143,162,160,160,  0,
-209,209,209, 77,238,221, 41, 20, 86, 71, 66, 42,149, 82,185, 92,206,200,229,242, 40,153, 76, 86,188,104,209,162, 19,238,202, 49,
-155,205, 96, 89, 83, 53,241, 59,146,255,241,227,199,209,183,111, 95,143,202, 53, 97,194, 31, 30,224,164, 73,147,144,153,153, 89,
-195,  0,104,140,182,226, 77, 61,156, 56,113,130,100,103,103,211, 17, 35, 70,220,241,219,158, 61,123,176,113,227,198,234,227,250,
-198, 45,220, 97,188, 55, 98, 58, 32, 42,166, 13,138, 85,149,216,242,194,120,132,147,193,200,255,223, 27,104, 63,182, 61, 50, 61,
- 32,127, 59,210,210,210, 40,  0,172, 90,181,170,193,109, 54,106,211, 33,232,174, 85,161, 88, 22, 83,239,117,103,197, 89,152,219,
-227, 22, 22,156,125,167, 65,245,217, 24,164,219,152, 50, 26, 35, 18,112,183,159,183,177,144,154,154,234,  7,224, 65,  0,  1, 14,
-167, 43,  0,228,174, 93,187,182,220, 93, 57,203, 86, 46, 99,216,219, 70,193,200,209, 99,197, 42,152,196,  2,  1,159,175, 54,136,
- 25,161, 80,207,241,130,252,205,172,196,100,226,151,220, 48,174,251,106,173, 97,202,180, 84, 11, 33,132,212, 53,102,196, 17, 21,
- 21, 21, 31,218,191,231,229,229,221,246,247,247,103,180, 90, 45,231,120, 77,255,254,253, 63,105, 76, 98,247,196, 80,240,202,  0,

@@ Diff output truncated at 10240 characters. @@




More information about the Bf-blender-cvs mailing list
--- trunk/blender/source/blender/makesdna/DNA_space_types.h	2007-09-21 20:46:17 UTC (rev 12103)
+++ trunk/blender/source/blender/makesdna/DNA_space_types.h	2007-09-22 06:58:40 UTC (rev 12104)
@@ -238,7 +238,9 @@
 	short imtypenr, lock;
 	short showspare, pin;
 	float zoom;
-	char dt_uv; char pad[7]; /* UV draw type */
+	char dt_uv; /* UV draw type */
+	char sticky; /* sticky selection type */ 
+	char pad[6]; 
 	
 	float xof, yof;					/* user defined offset, image is centered */
 	float centx, centy;				/* storage for offset while render drawing */
@@ -468,11 +470,11 @@
 #define SI_EDITTILE		1<<1
 #define SI_CLIP_UV		1<<2
 #define SI_DRAWTOOL		1<<3
-#define SI_STICKYUVS    1<<4
+#define SI_DEPRECATED1    1<<4	/* stick UVs to others in the same location */
 #define SI_DRAWSHADOW   1<<5
 #define SI_SELACTFACE   1<<6
-#define SI_DEPRECATED	1<<7
-#define SI_LOCALSTICKY  1<<8
+#define SI_DEPRECATED2	1<<7
+#define SI_DEPRECATED3  1<<8	/* stick UV selection to mesh vertex (UVs wont always be touching) */
 #define SI_COORDFLOATS  1<<9
 #define SI_PIXELSNAP	1<<10
 #define SI_LIVE_UNWRAP	1<<11

Modified: trunk/blender/source/blender/src/blenderbuttons.c
===================================================================